@@ -5,7 +5,7 @@
 # Joan Ntzougani, ✞
 
 package Dancer2::Plugin::WebService;
-our	$VERSION = '4.4.0';
+our	$VERSION = '4.4.1';
 use	strict;
 use	warnings;
 use Encode;
@@ -247,13 +247,21 @@ closedir DIR;
 			}
 		}
 
-	# Do not proceed if the posted data are not hash
-	$app->halt($plg->reply('error'=>"Posted data are not keys")) if 'HASH' ne ref $plg->{data};
+		# Do not proceed if the posted data are not hash
+		if ('HASH' ne ref $plg->{data}) {
 
-	# Delete not needed url parameters
+			if ('ARRAY' eq ref $plg->{data}) {
+			$plg->{data} = { data => $plg->{data} }
+			}
+			else {
+			$app->halt($plg->reply('error'=>'Posted data are not keys or list'))
+			}
+		}
+
+	# Delete not needed control url parameters
 	delete $app->request->query_parameters->{$_} foreach qw/from to sort pretty message/;
 
-	# We add to the data also any url parameter the user pass
+	# Use as data any url parameter
 	foreach (keys %{$app->request->query_parameters}) { $plg->data->{$_} = $app->request->query_parameters->{$_} }
 	}));
 
@@ -752,7 +760,7 @@ Dancer2::Plugin::WebService - RESTful Web Services with login, persistent data,
 
 =head1 VERSION
 
-version 4.4.0
+version 4.4.1
 
 =head2 SYNOPSIS
 
